#[repr(u8)]pub enum RtcOscBypass {
USED = 0,
BYPASS = 1,
}Variants
USED = 0
The RTC Oscillator operates normally as a crystal oscillator with the crystal connected between the RTC_XTALIN and RTC_XTALOUT pins.
BYPASS = 1
The RTC Oscillator is in bypass mode. In this mode a clock can be directly input into the RTC_XTALIN pin.
Implementations
Sourceimpl RtcOscBypass
impl RtcOscBypass