#[repr(u8)]pub enum RtcSubsecEna {
POWER_UP = 0,
POWERED_DOWN = 1,
}Variants
POWER_UP = 0
The sub-second counter (if implemented) is disabled. This bit is cleared by a system-level POR or BOD reset as well as a by the RTC_ENA bit (bit 7 in this register). On modules not equipped with a sub-second counter, this bit will always read-back as a ‘0’.
POWERED_DOWN = 1
The 32 KHz sub-second counter is enabled (if implemented). Counting commences on the start of the first one-second interval after this bit is set. Note: This bit can only be set after the RTC_ENA bit (bit 7) is set by a previous write operation. Note: The RTC sub-second counter must be re-enabled whenever the chip exits deep power-down mode.
Implementations
Sourceimpl RtcSubsecEna
impl RtcSubsecEna